package com.miaxis.app.controller.teachingVideo;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.teachingVideo.domain.TeachingVideoTypeInfo;
import com.miaxis.teachingVideo.dto.TeachingVideoInfoTypeIdDto;
import com.miaxis.teachingVideo.service.ITeachingVideoInfoService;
import com.miaxis.teachingVideo.service.ITeachingVideoTypeInfoService;
import com.miaxis.teachingVideo.vo.AppletTeachingVideoTypeInfoVo;
import com.miaxis.teachingVideo.vo.TeachingVideoInfoVo;
import io.swagger.annotations.*;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 【教学视频】Controller
 * @author wwl
 * @version 1.0
 * @date 2021/7/7 14:49
 */
@RestController
@AllArgsConstructor
@RequestMapping(Constants.OPEN_PREFIX+"/teachingVideo/info")
@Api(tags={"【小程序-教学视频】"})
public class AppletTeachingVideoInfoController extends BaseController {

    private final ITeachingVideoInfoService teachingVideoInfoService;

    private final ITeachingVideoTypeInfoService videoTypeInfoService;

    @GetMapping("/typeList")
    @ApiOperation("查询教学视频一级分类列表")
    public Response typeList(){
        return Response.success(videoTypeInfoService.list(new QueryWrapper<TeachingVideoTypeInfo>().eq("pid",0).eq("status",0).orderByAsc("type_sort")));
    }

    /**
     * 查询教学视频列表1

    @GetMapping("/list/{pid}")
    @ApiOperation("查询教学视频列表")
    public Response list(@ApiParam(name = "pid", value = "分类id", required = true)
                             @PathVariable("pid") String pid){
        return teachingVideoInfoService.queryTeachingVideoInfoList(pid);
    }
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取教学视频详细信息")
    public Response<TeachingVideoInfoVo> getInfo(
            @ApiParam(name = "id", value = "教学视频参数", required = true)
            @PathVariable("id") Long id
    ){
        return teachingVideoInfoService.getTeachingVideoDetailsById(id);
    }


    /**
     * 关键字搜索教学视频
     */
    @GetMapping("/search")
    @ApiOperation("关键字搜索教学视频")
    public Response search(String keyword){
        return teachingVideoInfoService.searchTeachingVideoInfoByKeyword(keyword);
    }


    /**
     * 根据分类ID 查询教学视频
     */
    @GetMapping("/getTeachingVideoByTypeId")
    @ApiOperation("根据分类ID查询教学视频")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public Response getTeachingVideoByTypeId(@ModelAttribute TeachingVideoInfoTypeIdDto teachingVideoInfoTypeIdDto){
        startPage();
        return teachingVideoInfoService.getTeachingVideoByTypeId(teachingVideoInfoTypeIdDto.getVideoTypeId());
    }


    /**
     * 查询教学视频分类树形列表
     */
    @GetMapping("/treeList")
    @ApiOperation("查询教学视频分类树形列表")
    public Response<List<AppletTeachingVideoTypeInfoVo>> treeList(){
        return videoTypeInfoService.selectAppletTeachingVideoTypeInfoTreeList();
    }
}
