package com.miaxis.pc.controller.teachingVideo;

import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.teachingVideo.domain.TeachingVideoTypeInfo;
import com.miaxis.teachingVideo.service.ITeachingVideoTypeInfoService;
import com.miaxis.teachingVideo.vo.TeachingVideoTypeInfoVo;
import io.swagger.annotations.*;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 【教学视频分类】Controller
 * @author wwl
 * @version 1.0
 * @date 2021/7/1 13:45
 */
@AllArgsConstructor
@RestController
@RequestMapping("/pc/videoType/info")
@Api(tags={"【pc-教学视频分类】"})
public class TeachingVideoTypeInfoController extends BaseController {

    private final ITeachingVideoTypeInfoService teachingVideoTypeInfoService;

    /**
     * 查询教学视频分类列表
     */
    @PreAuthorize("@ss.hasPermi('videoType:info:list')")
    @GetMapping("/list")
    @ApiOperation("查询教学视频分类列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TeachingVideoTypeInfo> list(@ModelAttribute TeachingVideoTypeInfo teachingVideoTypeInfo){
        startPage();
        List<TeachingVideoTypeInfo> list = teachingVideoTypeInfoService.selectTeachingVideoTypeInfoList(teachingVideoTypeInfo);
        return toResponsePageInfo(list);
    }

    /**
     * 查询教学视频分类树形列表
     */
    @PreAuthorize("@ss.hasPermi('videoType:info:treeList')")
    @GetMapping("/treeList")
    @ApiOperation("查询教学视频分类树形列表")
    public Response<List<TeachingVideoTypeInfoVo>> treeList(){
        return teachingVideoTypeInfoService.selectTeachingVideoTypeInfoTreeList();
    }


    /**
     * 获取教学视频分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('videoType:info:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取教学视频分类详细信息")
    public Response<TeachingVideoTypeInfo> getInfo(
            @ApiParam(name = "id", value = "教学视频分类参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(teachingVideoTypeInfoService.getById(id));
    }

    /**
     * 新增教学视频分类
     */
    @PreAuthorize("@ss.hasPermi('videoType:info:add')")
    @Log(title = "教学视频分类", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增教学视频分类")
    public Response<Integer> add(@RequestBody TeachingVideoTypeInfo teachingVideoTypeInfo){
        return toResponse(teachingVideoTypeInfoService.save(teachingVideoTypeInfo) ? 1 : 0);
    }

    /**
     * 修改教学视频分类
     */
    @PreAuthorize("@ss.hasPermi('videoType:info:edit')")
    @Log(title = "教学视频分类", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改教学视频分类")
    public Response<Integer> edit(@RequestBody TeachingVideoTypeInfo teachingVideoTypeInfo){
        return toResponse(teachingVideoTypeInfoService.updateById(teachingVideoTypeInfo) ? 1 : 0);
    }

    /**
     * 删除教学视频分类
     */
    @PreAuthorize("@ss.hasPermi('videoType:info:remove')")
    @Log(title = "教学视频分类", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping("/{ids}")
    @ApiOperation("删除教学视频分类")
    public  Response remove(
            @ApiParam(name = "ids", value = "教学视频分类ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return teachingVideoTypeInfoService.removeVideoTypeByIds(ids);
    }


}
