package com.miaxis.test;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.miaxis.ZzjsApplication;
import com.miaxis.car.domain.CarBrandInfo;
import com.miaxis.car.domain.CarParameterData;
import com.miaxis.car.mapper.CarParameterDataMapper;
import com.miaxis.car.service.ICarBrandInfoService;
import com.miaxis.common.enums.FileUploadTypeEnum;
import com.miaxis.feign.service.ICarService;
import com.qcloud.cos.COSClient;
import com.qcloud.cos.model.ObjectMetadata;
import com.qcloud.cos.model.PutObjectRequest;
import com.qcloud.cos.model.PutObjectResult;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;

import javax.annotation.Resource;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.*;

/**
 * @author wwl
 * @version 1.0
 * @date 2021/5/21 11:51
 */
@SpringBootTest(classes = ZzjsApplication.class)
@RunWith(SpringRunner.class)
public class UpdateCarTest {

    @Autowired
    private ICarService carService;

    @Autowired
    private ICarBrandInfoService carBrandInfoService;

    @Autowired
    private COSClient cosClient;

    @Resource
    private CarParameterDataMapper carParameterDataMapper;

    private static String bucketName="t1-1305573081";
    private static String path="https://t1-1305573081.file.myqcloud.com";
    private static String preffix="t1";

    /**
     * 获取第三方汽车品牌接口
     * @return
     */
    @Test
    public void carBrand(){
        String result = carService.car("brand","0,1,2,3","300");
        JSONObject jsonString = JSONObject.parseObject(result);
        List<Map> info = (List<Map>)jsonString.get("info");
        ArrayList<CarBrandInfo> carBrandInfos = new ArrayList<>();
        for (Map map : info) {
            carBrandInfos.add(JSON.parseObject(JSON.toJSONString(map), CarBrandInfo.class));
        }
//        carBrandInfoService.saveBatch(carBrandInfos);
        System.out.println(carBrandInfos);
    }


    @Test
    public void test1() throws Exception {

        List<CarBrandInfo> list = carBrandInfoService.list(new QueryWrapper<CarBrandInfo>().like("img", "car"));

        for (CarBrandInfo carBrandInfo : list) {
            URL httpUrl = new URL(carBrandInfo.getImg());
            HttpURLConnection conn = (HttpURLConnection)httpUrl.openConnection();
            conn.setRequestMethod("GET");
            conn.setConnectTimeout(5 * 1000);
            //通过输入流获取图片数据
            InputStream inStream = conn.getInputStream();
            //从输入流中获取得到图片的二进制数据
            ByteArrayOutputStream outStream = new ByteArrayOutputStream();
            byte[] buffer = new byte[1024];
            int len = 0;
            while( (len=inStream.read(buffer)) != -1 ){
                outStream.write(buffer, 0, len);
            }
            byte[] btImg = outStream.toByteArray();
            InputStream byteArrayInputStream = new ByteArrayInputStream(btImg);
            int length = btImg.length;
            ObjectMetadata objectMetadata = new ObjectMetadata();
            // 从输入流上传必须制定content length, 否则http客户端可能会缓存所有数据，存在内存OOM的情况
            objectMetadata.setContentLength(length);
            // bucket的命名规则为{name}-{appid} ，此处填写的存储桶名称必须为此格式
            String bucketName = this.bucketName;

            Calendar cal = Calendar.getInstance();
            int year = cal.get(Calendar.YEAR);
            int month=cal.get(Calendar.MONTH)+ 1;
            int day=cal.get(Calendar.DATE);

            //存储的文件名
            String storagefileName = System.currentTimeMillis() + ".png";
            // 指定要上传到 COS 上的路径
            String key = "/"+this.preffix+"/"+FileUploadTypeEnum.CAR_BRAND.getFileType()+"/"+year+"/"+month+"/"+day+"/"+storagefileName;
            PutObjectRequest putObjectRequest = new PutObjectRequest(bucketName, key, byteArrayInputStream,objectMetadata);
            PutObjectResult putObjectResult = cosClient.putObject(putObjectRequest);
            String fileUrl=this.path + putObjectRequest.getKey();
            inStream.close();
            System.out.println("--------------"+fileUrl);
            System.out.println("--------------"+key);

            //更新汽车品牌logo
            carBrandInfo.setImg(fileUrl);
            carBrandInfo.setImgPath(key);
            carBrandInfoService.updateById(carBrandInfo);
        }

    }


    /**
     * 新增二手车参数
     * @return
     */
    @Test
    public void addUsedCarData(){
        //车型  model
        List<String> strings1 = Arrays.asList("轿车","SUV", "MPV", "跑车","面包车", "皮卡", "微卡");
        //价格 selling_price
        List<String> strings2 = Arrays.asList("1万元以内","1-2万元", "2-3万元", "3-5万元","5-8万元", "8-12万元", "12-18万元", "18-24万元", "24-40万元", "40万元以上");
        //变速箱 transmission_case
        List<String> strings3 = Arrays.asList("手动","自动");
        //排放标准---------
        List<String> strings4 = Arrays.asList("国二","国三","国四","国五","国六");
        //排量 vehicle_displacement
        List<String> strings5 = Arrays.asList("1.0L及以下","1.1L-1.6L","1.7L-2.0L","2.1L-2.5L","2.6L-3.0L","3.1L-4.0L","4.0L以上");
        //座位数 number_of_seats
        List<String> strings6 = Arrays.asList("2座","4座","5座","6座","7座");
        //燃料类型 fuel
        List<String> strings7 = Arrays.asList("汽油","柴油","电动","油电混动");
        //驱动 driving_mode
        List<String> strings8 = Arrays.asList("前驱","后驱","四驱");
        //结构 body_structure
        List<String> strings9 = Arrays.asList("两厢","三厢", "掀背", "旅行版","硬顶敞篷车","软顶敞篷车","硬顶跑车","客车","货车");
        //里程 mileage
        List<String> strings10 = Arrays.asList("1万公里内","1-3万公里", "3-5万公里", "5-8万公里","8-12万公里","12-18万公里","18万公里以上");

        for (int i = 0; i < strings1.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings1.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("model");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings2.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings2.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("selling_price");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings3.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings3.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("transmission_case");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings4.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings4.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("emission_standard");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings5.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings5.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("vehicle_displacement");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings6.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings6.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("number_of_seats");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings7.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings7.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("fuel");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings8.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings8.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("driving_mode");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings9.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings9.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("body_structure");
            carParameterDataMapper.insert(carParameterData);
        }
        for (int i = 0; i < strings10.size(); i++) {
            int s = i;
            CarParameterData carParameterData = new CarParameterData();
            carParameterData.setParameterName(strings10.get(i));
            carParameterData.setParameterValue(String.valueOf(s+1));
            carParameterData.setParameterSort(s+1);
            carParameterData.setParameterType("mileage");
            carParameterDataMapper.insert(carParameterData);
        }


    }


}
