package com.miaxis.collection.strategy;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.miaxis.car.domain.CarBrandInfo;
import com.miaxis.car.domain.UsedCarFile;
import com.miaxis.car.domain.UsedCarInfo;
import com.miaxis.car.mapper.UsedCarFileMapper;
import com.miaxis.car.service.ICarBrandInfoService;
import com.miaxis.car.service.IUsedCarInfoService;
import com.miaxis.collection.vo.AppletCollectionVo;
import com.miaxis.common.strategy.StrategyManager;
import com.miaxis.file.domain.FileInfo;
import com.miaxis.file.service.IFileInfoService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;

/**
 * car策略具体实现
 * @author wwl
 * @date 2021/7/26 15:38
 */
@Component
@RequiredArgsConstructor
public class CarStrategy implements BaseStrategy {

    private final IUsedCarInfoService usedCarInfoService;

    private final UsedCarFileMapper usedCarFileMapper;

    private final IFileInfoService fileInfoService;

    private final ICarBrandInfoService carBrandInfoService;

    /**
     * @PostConstruct：容器初始化时执行该方法
     */
    @PostConstruct
    public void register() {
        StrategyManager.getInstance().register(this, true);
    }

    @Override
    public String getName() {
        return "car";
    }

    @Override
    public AppletCollectionVo getCollectionVo(Long id,Long collectionId) {
        UsedCarInfo carInfo = usedCarInfoService.getById(collectionId);
        UsedCarFile usedCarFile = usedCarFileMapper.selectOne(new QueryWrapper<UsedCarFile>()
                .eq("used_car_id", collectionId)
                .eq("sign", "main"));
        FileInfo fileInfo = new FileInfo();
        if (usedCarFile != null){
            fileInfo = fileInfoService.getById(usedCarFile.getFileId());
        }
        CarBrandInfo brandInfo = carBrandInfoService.getById(carInfo.getCarBrand());
        AppletCollectionVo appletCollectionVo = new AppletCollectionVo();
        appletCollectionVo.setId(id);
        appletCollectionVo.setCollectionId(collectionId);
        appletCollectionVo.setTitle(brandInfo.getName() + "--"+carInfo.getCarSeries());
        appletCollectionVo.setIntroduction(carInfo.getVehicleIntroduction());
        appletCollectionVo.setPrice(carInfo.getSellingPrice());
        appletCollectionVo.setFileUrl(fileInfo.getFileUrl());
        appletCollectionVo.setCollectionType("car");

        return appletCollectionVo;
    }
}
