package com.miaxis.collection.strategy;

import com.miaxis.collection.vo.AppletCollectionVo;
import com.miaxis.common.strategy.StrategyManager;
import com.miaxis.file.domain.FileInfo;
import com.miaxis.file.service.IFileInfoService;
import com.miaxis.teachingVideo.domain.TeachingVideoInfo;
import com.miaxis.teachingVideo.service.ITeachingVideoInfoService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;

/**
 * video策略具体实现
 * @author wwl
 * @date 2021/7/26 15:38
 */
@Component
@RequiredArgsConstructor
public class VideoStrategy implements BaseStrategy {

    private final ITeachingVideoInfoService teachingVideoInfoService;//学车视频

    private final IFileInfoService fileInfoService;

    /**
     * @PostConstruct：容器初始化时执行该方法
     */
    @PostConstruct
    public void register() {
        StrategyManager.getInstance().register(this, true);
    }

    @Override
    public String getName() {
        return "video";
    }


    @Override
    public AppletCollectionVo getCollectionVo(Long id,Long collectionId) {
        TeachingVideoInfo videoInfo = teachingVideoInfoService.getById(collectionId);
        FileInfo fileInfo = fileInfoService.getById(videoInfo.getCoverFileId());
        AppletCollectionVo appletCollectionVo = new AppletCollectionVo();
        appletCollectionVo.setId(id);
        appletCollectionVo.setCollectionId(collectionId);
        appletCollectionVo.setTitle(videoInfo.getTitle());
        appletCollectionVo.setIntroduction(videoInfo.getVideoDescribe());
        appletCollectionVo.setFileUrl(fileInfo.getFileUrl());
        appletCollectionVo.setCollectionType("video");
        return appletCollectionVo;
    }
}
