package com.miaxis.teachingVideo.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.miaxis.common.core.domain.Response;
import com.miaxis.teachingVideo.domain.TeachingVideoInfo;
import com.miaxis.teachingVideo.domain.TeachingVideoTypeInfo;
import com.miaxis.teachingVideo.dto.TeachingVideoInfoDto;
import com.miaxis.teachingVideo.dto.TeachingVideoInfoTypeIdDto;
import com.miaxis.teachingVideo.vo.TeachingVideoInfoVo;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 教学视频Service接口
 * @author wwl
 * @version 1.0
 * @date 2021/7/1 14:47
 */
public interface ITeachingVideoInfoService extends IService<TeachingVideoInfo> {

    /**
     * 查询教学视频列表
     *
     * @param teachingVideoInfo 教学视频
     * @return 教学视频集合
     */
    List<TeachingVideoInfoVo> selectTeachingVideoInfoList(TeachingVideoInfo teachingVideoInfo);

    /**
     * 获取教学视频详细信息
     * @param id
     * @return
     */
    Response<TeachingVideoInfoVo> getTeachingVideoDetailsById(Long id);

    /**
     *  新增教学视频
     * @param teachingVideoInfo
     * @return
     */
    Response saveTeachingVideo(TeachingVideoInfoDto teachingVideoInfo);

    /**
     * 修改教学视频
     * @param teachingVideoInfo
     * @return
     */
    Response updateTeachingVideoById(TeachingVideoInfoDto teachingVideoInfo);

    /**
     * 删除教学视频(伪删除)
     * @param ids
     * @return
     */
    Response<Integer> removeTeachingVideoByIds(Long[] ids);


    /**
     * 上架教学视频
     * @param ids
     * @return
     */
    Response removePutShelfByIds(Long[] ids);

    /**
     * 下架教学视频
     * @param ids
     * @return
     */
    Response removeOffShelfByIds(Long[] ids);

    /**
     * applet
     * 查询教学视频列表
     * @param pid
     * @return
     */
    Response queryTeachingVideoInfoList(String pid);

    /**
     * 根据关键字搜索教学视频
     * @param keyword
     * @return
     */
    Response searchTeachingVideoInfoByKeyword(String keyword);

    /**
     * 封面上传
     * @param fileId
     * @param coverFile
     * @return
     */
    Response coverUp(String fileId, MultipartFile coverFile);

    /**
     * 根据类型ID搜索教学视频
     * @param typeId
     * @return
     */
    Response getTeachingVideoByTypeId(Long typeId);
}
